##########
Tutorials
##########

These tutorials provide a step-by-step guide to performing specific
tasks.

These guides do not cover the individual beamlines thoroughly.

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   knife_scan.ipynb
   xafs_energy_scan.rst
   area_detectors.rst
   fly_scanning.ipynb
